@@ -2,10 +2,17 @@ from django.conf import settings
 from django.contrib.sites.models import Site
 
 
-def get_site_id(request):
+def get_site(request):
     if hasattr(request, 'site') and isinstance(request.site, Site):
-        return request.site.pk
+        return request.site
     try:
-        return Site.objects.get(pk=settings.SITE_ID).pk
+        return Site.objects.get(pk=settings.SITE_ID)
     except Site.DoesNotExist:
         return None
+
+
+def get_site_id(request):
+    site = get_site(request)
+    if site is None:
+        return None
+    return site.pk
